import java.awt.Toolkit;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.event.MouseEvent;

import jusecase.components.ScriptedComponent;

/**
 * Sets up recorders/simulators for DoubleClickLabel double-click events.
 * 
 */
public class ScriptedDoubleClickLabel extends ScriptedComponent
{
    private final DoubleClickLabel labelM;


    /**
     * Sets up a recorder/simulator for DoubleClickLabel events.
     */
    public static void connect(String commandName, DoubleClickLabel label)
    {
	new ScriptedDoubleClickLabel(commandName, label);
    }

    
    private ScriptedDoubleClickLabel(String commandName, DoubleClickLabel label)
    {
	super(commandName, label);

	labelM = label;
	
	// the recorder listens for action events generated by the DoubleClickLabel
	labelM.addActionListener(new ActionListener()
	    {
		public void actionPerformed(ActionEvent event)
		{
		    // each double-click is a separate event, so don't overwrite
		    // instances of this event recorded earlier
		    boolean overWrite = false;
		    recordCommand("", overWrite);
		}
	    });
    }


    /**
     * Always returns true to override default focus behavior
     */
    protected boolean hasCustomFocus()
    {
	// JUseCase will look at hasCustomFocus when deciding whether or not to
	// record the events detected by this recorder object. Normally, JUseCase
	// does not record events for components that do not have focus, but since
	// labels never have focus, we have to override this behavior and always
	// return true.
	return true;
    }


    /**
     * Simulates a double-click on a DoubleClickLabel
     */
    protected void performCommand(String params)
    {
	// faked mouse event details
	int id = MouseEvent.MOUSE_CLICKED;
	long when = System.currentTimeMillis();
	int modifiers = 0;
	int x = (int) (labelM.getWidth() / 2);
	int y = (int) (labelM.getHeight() / 2);
	int clicks = 2;
	boolean popup = false;
	int button = MouseEvent.BUTTON1;

	// post a double-click event to the event queue
	MouseEvent doubleClickEvent = new MouseEvent(labelM, id, when, modifiers, x, y, clicks, popup, button);
	Toolkit.getDefaultToolkit().getSystemEventQueue().postEvent(doubleClickEvent);	
    }
}
